
#ifndef _C11_ca514_
#define _C11_ca514_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1184_13026(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit514(void);
extern char *(*R2988[])();

#ifdef __cplusplus
}
#endif

#endif
